@@ -1,7 +1,7 @@
 from .utils import *
 from abstract_apis import *
 
-def asyncCallRequest(endpoint,*args,**kwargs):
+async def asyncCallRequest(endpoint,*args,**kwargs):
   endpoint = make_endpoint(endpoint)
   return await asyncPostRequest(getCallUrl(),kwargs,endpoint=endpoint)
 
