@@ -3,14 +3,14 @@ from abstract_apis import *
 from .utils import *
 import requests
 async def get_rate_limit_url(method_name, *args, **kwargs):
-    endpoint = make_endpoint("/rate_limit")
+    url = getEndpointUrl("/rate_limit")
     for arg in args:
         if "method" not in kwargs:
             kwargs["method"] = arg
-    return await asyncGetRequest(getCallUrl(), kwargs, endpoint=endpoint)
+    return await asyncGetRequest(url, kwargs)
     
 async def log_response(method_name, response_data, *args, **kwargs):
-    endpoint = make_endpoint("/log_response")
+    url = getEndpointUrl("/log_response")
     # Assuming that `args` is supposed to update `kwargs` for unspecified keys
     for arg in args:
         if "method" not in kwargs:
@@ -22,13 +22,6 @@ async def log_response(method_name, response_data, *args, **kwargs):
         "method": kwargs.get("method", method_name),
         "response_data": kwargs.get("response_data", response_data)
     }
-    return await asyncPostRequest(getCallUrl(), kwargs, endpoint=endpoint)
+    return await asyncPostRequest(url, kwargs, endpoint=endpoint)
+
 
-async def getAsyncLimitedRequest(endpoint,**kwargs):
-    url = await get_rate_limit_url(method_name)
-    response = await asyncPostRequest(url=url,data=kwargs)
-    await log_response(method_name, response_data)
-    return response
-def callSolcatcherRpc(endpoint,**kwargs)
-    response = asyncio.run(asyncPostRequest(endpoint=endpoint,data=kwargs))
-    return response
