@@ -1,5 +1,10 @@
 from ..abstract_async_requests import callSolcatcherRpc
 from abstract_utilities import eatAll,make_list
+def search_for_account_index(data,index_number):
+    for index_data in data:
+        if str(index_data.get('accountIndex')) == str(index_number):
+            return index_data
+          
 def get_txn_data(file_path=None):
   file_path = file_path or 'txnData.json'
   return safe_read_from_json(file_path)
@@ -194,6 +199,7 @@ class saveInstructions:
     self.inner_instructions = self.associate_all_inner_instructions()
     return self.get_all_instructions()
 
+
 class TransactionProcessor:
     def __init__(self, txnData=None,signature=None,instruction_mgr = None,account_mgr=None,log_mgr=None,**kwargs):
         txnData = txnData or self.getTransacion(signature,**kwargs)
@@ -211,15 +217,94 @@ class TransactionProcessor:
       return self.account_mgr.accountKeys
 
     def get_txn_data(self):
-      input(self.txnData)
-      txnData['transaction']['message']['instructions'] = self.instruction_mgr.instructions
-      txnData['meta']['innerInstructions'][0]['instructions'] = self.instruction_mgr.inner_instructions
+      self.txnData['transaction']['message']['instructions'] = self.instruction_mgr.instructions
+      self.txnData['meta']['innerInstructions'][0]['instructions'] = self.instruction_mgr.inner_instructions
       return self.txnData
     
     def getTransacion(self,signature,**kwargs):
       kwargs['signature']=signature
       return callSolcatcherRpc('getTransaction',**kwargs)
+
+def get_test_signature():
+  return "RwJcLtyVyPSBWfNCzNcCaqKrmTmaKqDezzMFXTubmPGM9AfjdMW2tg9Xb1Dm8ZvHDYsH3Za22zWq2N8sQKxd1uq"
+def get_txnMgr(txnData=None,signature=None):
+  return TransactionProcessor(txnData=txnData,signature=signature)
+class txnManager:
+    def __init__(self, txnData=None, signature=None, txn_mgr=None, acct_mgr=None):
+        self.signature = signature or get_test_signature()
+        self.txn_mgr = txn_mgr or get_txnMgr(txnData=txnData, signature=self.signature)
+        self.acct_mgr = acct_mgr or self.txn_mgr.account_mgr
+        self.txnData = self.txn_mgr.txnData or get_transaction(self.signature)
+        self.preBalances = self.txnData['meta']['preBalances']
+        self.postBalances = self.txnData['meta']['postBalances']
+        self.preTokenBalances = self.txnData['meta']['preTokenBalances']
+        self.postTokenBalances = self.txnData['meta']['postTokenBalances']
+        self.all_txns = {"Address":[],"Owner":[],'Balance Before':[],"Balance After":[],"Change":[],"Token":[]}
+        self.accountKeys = self.acct_mgr.accountKeys
+        self.all_txns = {"Address": [], "Owner": [], 'Balance Before': [], "Balance After": [], "Change": [], "Token": []}
+        
+        # Create a dictionary for quick lookups by accountIndex
+        self.index_to_postToken = {token['accountIndex']: token for token in self.postTokenBalances}
+    def get_from_postToken_index(self,index):
+      return search_for_account_index(self.postTokenBalances,index)
+    def get_postToken_amnt_dict(self,index):
+      return self.get_from_postToken_index(index)
+    def get_from_preToken_index(self,index):
+      return search_for_account_index(self.preTokenBalances,index)
+    def get_preToken_amnt_dict(self,index):
+      return self.get_from_preToken_index(index)
+    def get_amount_dict(self, amount, decimals=9):
+        if isinstance(amount, dict):
+            amount_dict = get_any_value(amount, 'uiTokenAmount')
+            amount = get_any_value(amount_dict, 'amount')
+            decimals = get_any_value(amount_dict, 'decimals')
+        return exponential(amount, decimals, -1)
+
+    def create_token_txns(self):
+        dont_use = []
+        for i,balances in enumerate([self.preTokenBalances,self.postTokenBalances]):
+            for post in balances:
+                index = post.get('accountIndex')
+                if index not in dont_use:
+                    dont_use.append(index)
+                    after = self.get_postToken_amnt_dict(index)
+                    change = self.get_amount_dict(post)
+                    if after!=None and change !=None:
+                        before = after-change
+                        address = self.acct_mgr.get_account_from_index(index)
+                        owner = post.get('owner')
+                        token = post.get('mint')
+                        if i == 0:
+                            pre_change = change
+                            change = before
+                            before = pre_change
+                        self.all_txns["Address"].append(address)
+                        self.all_txns["Owner"].append(owner)
+                        self.all_txns['Balance Before'].append(before)
+                        self.all_txns["Balance After"].append(after)
+                        self.all_txns["Change"].append(change)
+                        self.all_txns["Token"].append(token)
+        return self.all_txns
+      
+    def visualize_txns(self):
+        if not self.all_txns['Address']:  # Check if transactions are populated
+            self.create_token_txns()  # Populate the transactions if not already done
+        
+        df = pd.DataFrame(self.all_txns)
+        pd.set_option('display.max_columns', None)  # To display all columns
+        print(df)
+
+        return df
+      
+def get_token_txn_data(txnData=None,signature=None):
+  txn_mgr = txnManager(txnData=txnData,signature=signature)
+  return txn_mgr.create_token_txns()
+
+def display_txn_data(txnData=None,signature=None):
+  txn_mgr = txnManager(txnData=txnData,signature=signature)
+  return txn_mgr.visualize_txns()
+
 def get_transaction(signature,**kwargs):
   kwargs['signature']=signature
-  txn_mgr = TransactionProcessor(**kwargs)
-  return txn_mgr.get_txn_data()
+  txnData_mgr = TransactionProcessor(**kwargs)
+  return txnData_mgr.get_txn_data()
